summaryrefslogtreecommitdiff
path: root/indra/newview/lldrawable.h
diff options
context:
space:
mode:
authorRichard Linden <none@none>2013-08-09 17:11:19 -0700
committerRichard Linden <none@none>2013-08-09 17:11:19 -0700
commite340009fc59d59e59b2e8d903a884acb76b178eb (patch)
tree6c42d6e0031ef1dbe841fd05cd5d62d5b6b48525 /indra/newview/lldrawable.h
parent8d3daa141e9ea14f533559843d77ab5c0f715421 (diff)
second phase summer cleaning
replace llinfos, lldebugs, etc with new LL_INFOS(), LL_DEBUGS(), etc.
Diffstat (limited to 'indra/newview/lldrawable.h')
-rwxr-xr-xindra/newview/lldrawable.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/indra/newview/lldrawable.h b/indra/newview/lldrawable.h
index 08fbd7d211..efb3e1d89d 100755
--- a/indra/newview/lldrawable.h
+++ b/indra/newview/lldrawable.h
@@ -71,7 +71,7 @@ public:
const LLDrawable& operator=(const LLDrawable& rhs)
{
- llerrs << "Illegal operation!" << llendl;
+ LL_ERRS() << "Illegal operation!" << LL_ENDL;
return *this;
}
@@ -315,19 +315,19 @@ private:
inline LLFace* LLDrawable::getFace(const S32 i) const
{
//switch these asserts to llerrs -- davep
//llassert((U32)i < mFaces.size());
//llassert(mFaces[i]);
if ((U32) i >= mFaces.size())
{
- llwarns << "Invalid face index." << llendl;
+ LL_WARNS() << "Invalid face index." << LL_ENDL;
return NULL;
}
if (!mFaces[i])
{
- llwarns << "Null face found." << llendl;
+ LL_WARNS() << "Null face found." << LL_ENDL;
return NULL;
}
@@ -315,19 +315,19 @@ private:
inline LLFace* LLDrawable::getFace(const S32 i) const
{
- //switch these asserts to llerrs -- davep
+ //switch these asserts to LL_ERRS() -- davep
//llassert((U32)i < mFaces.size());
//llassert(mFaces[i]);